<?php
/**
 * @file
 * Admin forms for warden
 */

/**
 * Page callback: System settings settings.
 *
 * @see warden_menu()
 */
function warden_form($form, &$form_state) {

  $form['warden_server_host_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Warden Dashboard URL'),
    '#description' => t('URL of the Warden Dashboard. This is where this this will be registered with for monitoring.'),
    '#default_value' => variable_get('warden_server_host_path', ''),
  );

  if (variable_get('warden_server_host_path', '') == '') {
    return system_settings_form($form);
  }

  $form['warden_public_allow_public'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow public calls'),
    '#description' => t('Allow calls from ip-adresses as defined below. Please note that they should be comma separated.'),
    '#default_value' => variable_get('warden_public_allow_public', '0'),
  );

  $form['warden_public_allow_ips'] = array(
    '#type' => 'textfield',
    '#title' => t('Comma seperated list of allowed IP addresses'),
    '#default_value' => variable_get('warden_public_allow_ips', '127.0.0.1,::1'),
    '#states' => array(
      'visible' => array(
        ':input[name="warden_public_allow_public"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['add_site'] = array(
    '#type' => 'submit',
    '#value' => t('Add this site to your Warden Dashboard'),
    '#submit' => array('warden_add_site'),
  );

  /*$form['warden_need_protect_token'] = array(
    '#type' => 'checkbox',
    '#title' => t('Protect all calls using a unique token'),
    '#description' => t('Require that a code is passed to the url to view the JSON ouput. You need the following private key to open the page: @token',
      array("@token" => variable_get('warden_token', 'Error-no-token'))),
    '#default_value' => variable_get('warden_need_protect_token', 1),
    '#states' => array(
      'checked' => array(
        array(':input[name="warden_need_protect_token"]' => array('checked' => TRUE)),
      ),
    ),
  );

  $form['warden_need_encryption'] = array(
    '#type' => 'checkbox',
    '#title' => t('Protect all calls using encryption'),
    '#description' => t('Selecting this option will encrypt all output, rendering the data useless for hackers during a man-in-the-middle attack. You need the following private key to decode the message: @encrypt_token ',
      array("@encrypt_token" => variable_get("warden_encrypt_token", 'Error-no-token'))),
    '#default_value' => variable_get('warden_need_encryption', 1),
    '#states' => array(
      'checked' => array(
        array(':input[name="warden_need_encryption"]' => array('checked' => TRUE)),
      ),
    ),
  );*/

  $form['warden_do_match_core'] = array(
    '#type' => 'checkbox',
    '#title' => t('Report core modules'),
    '#description' => t('Include core modules and their versions in your report. This option is required for reporting of your website\'s Drupal version and available updates.'),
    '#default_value' => variable_get('warden_do_match_core', '1'),
  );

  $form['warden_do_match_contrib'] = array(
    '#type' => 'checkbox',
    '#title' => t('Report contrib modules'),
    '#description' => t('Include contrib modules and their versions in your report. This option is required for reporting of all your website\'s modules versions and available updates.'),
    '#default_value' => variable_get('warden_do_match_contrib', '1'),
  );

  $form['warden_match_contrib_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Where are your contrib modules stored ?'),
    '#description' => t('When unsure, leave this option as set.'),
    '#default_value' => variable_get('warden_match_contrib_mode', 0),
    '#options' => array(
      0 => 'sites/*/modules/',
      1 => 'sites/*/modules/contrib/',
      2 => 'Other'
    ),
    '#states' => array(
      'visible' => array(
        ':input[name="warden_do_match_contrib"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['warden_preg_match_contrib'] = array(
    '#type' => 'textfield',
    '#title' => t('Regular expression to match contrib modules'),
    '#default_value' => variable_get('warden_preg_match_contrib', '{^sites\/([A-z,\.,\-]+)\/modules\/contrib\/*}'),
    '#states' => array(
      'visible' => array(
        ':input[name="warden_match_contrib_mode"]' => array('value' => 2),
      ),
    ),
  );

  $form['warden_do_match_custom'] = array(
    '#description' => t('Scan for custom modules using a regular expression.'),
    '#type' => 'checkbox',
    '#title' => t('Report custom modules'),
    '#default_value' => variable_get('warden_do_match_custom', '0'),
    '#states' => array(
      'visible' => array(
        ':input[name="warden_match_contrib_mode"]' => array('value' => 2),
      ),
    ),
  );

  $form['warden_preg_match_custom'] = array(
    '#type' => 'textfield',
    '#title' => t('Regular expression to match custom modules'),
    '#default_value' => variable_get('warden_preg_match_custom', '{^sites\/([A-z,\.,\-]+)\/modules\/custom\/*}'),
    '#states' => array(
      'visible' => array(
        ':input[name="warden_do_match_custom"]' => array('visible' => TRUE),
      ),
    ),
  );

  return system_settings_form($form);
}

function warden_add_site($form, &$form_state) {
  global $base_url;
  $site_url = urlencode($base_url);
  $site_url .= "|" . variable_get('warden_token', 'Error-no-token');
  $site_url .= "|" . variable_get('warden_encrypt_token', 'Error-no-token');
  $site_host_path = variable_get('warden_server_host_path', '');
  $url = $site_host_path . '/sites/add?siteUrl=' . $site_url;

  if (module_exists('overlay') && overlay_get_mode() == 'child') {
    unset($_GET['destination']);
    overlay_close_dialog($url, array('external' => TRUE));
    $form_state['redirect'] = FALSE;
  } else {
    $form_state['redirect'] = $url;
  }
}
